@@ -163,10 +163,10 @@ sub getFieldValue {
     return undef unless ref $entry eq 'HASH';
     if ($entry->{getter}){
         if (ref $entry->{getter} eq 'CODE'){
-            my $start = time();
+            my $start = time;
             my $data = $entry->{getter}->($self);
-            $self->log->debug(sprintf("ran getter %s: %0.2fs",$field,time()-$start));
-            return $data'
+            $self->log->debug(sprintf("ran getter %s: %0.2fs",$field,time-$start));
+            return $data;
         }
         else {
             $self->log->warn('Plugin instance'.$self->name." field $field has a broken getter\n");
